@@ -63,17 +63,15 @@ use Mojolicious::Commands;
 
 # use Contenticious
 $ENV{MOJO_HOME} = dirname(__FILE__);
-my $app = Contenticious->new;
 
 # Contenticious dump command
 if (defined $ARGV[0] and $ARGV[0] eq 'dump') {
-    Contenticious::Commands->new(app => $app)->dump;
+    Contenticious::Commands->new(app => Contenticious->new)->dump;
 }
 
 # use Contenticious as mojo app
 else {
-    $ENV{MOJO_APP} = $app;
-    Mojolicious::Commands->start;
+    Mojolicious::Commands->start_app('Contenticious');
 }
 
 @@ pages/index.md
